summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-09-14 14:20:37 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-09-14 14:23:40 -0500
commit3fe1616c4525ed2e50d84228fc69ac59c4efaa75 (patch)
tree7aebf71a06c7b7bdf47ce12d49dea1a7ce82efbf /png.h
parent0df3198719e49f5cd7b7c9408618e4b47c06db8c (diff)
downloadlibpng-3fe1616c4525ed2e50d84228fc69ac59c4efaa75.tar.gz
[libpng16] Bump version to 1.6.14beta02
Diffstat (limited to 'png.h')
-rw-r--r--png.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/png.h b/png.h
index be436b02a..5e1ad18b4 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.14beta01 - September 14, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.14beta01 - September 14, 2014: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -203,7 +203,7 @@
* 1.6.13beta01-04 16 10613 16.so.16.13[.0]
* 1.6.13rc01-02 16 10613 16.so.16.13[.0]
* 1.6.13 16 10613 16.so.16.13[.0]
- * 1.6.14beta01 16 10614 16.so.16.14[.0]
+ * 1.6.14beta01-02 16 10614 16.so.16.14[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -235,7 +235,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.6.14beta01, September 14, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -353,7 +353,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.6.14beta01 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -415,9 +415,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.6.14beta01"
+#define PNG_LIBPNG_VER_STRING "1.6.14beta02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.6.14beta01 - September 14, 2014\n"
+ " libpng version 1.6.14beta02 - September 14, 2014\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -431,7 +431,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 01
+#define PNG_LIBPNG_VER_BUILD 02
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -561,7 +561,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_6_14beta01;
+typedef char* png_libpng_version_1_6_14beta02;
/* Basic control structions. Read libpng-manual.txt or libpng.3 for more info.
*
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.14beta01 - September 14, 2014
+ * libpng version 1.6.14beta02 - September 14, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.14beta01 - September 14, 2014: Glenn
+ * libpng versions 0.97, January 1998, through 1.6.14beta02 - September 14, 2014: Glenn
* See also "Contributing Authors", below.
*
@@ -235,7 +235,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.6.14beta01, September 14, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.6.14beta02, September 14, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -353,7 +353,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.6.14beta01 are Y2K compliant. It is my belief that
+ * upward through 1.6.14beta02 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*